@@ -178,7 +178,7 @@ class Party:
                     continue
                 vals = {}
                 vals['value'] = email.value
-                res['contact_mechanisms'].append(('write', cm.id, vals))
+                res['contact_mechanisms'].append(('write', [cm.id], vals))
                 i += 1
             try:
                 new_emails = vcard.contents.get('email', [])[i:]
@@ -207,7 +207,7 @@ class Party:
                     continue
                 vals = {}
                 vals['value'] = tel.value
-                res['contact_mechanisms'].append(('write', cm.id, vals))
+                res['contact_mechanisms'].append(('write', [cm.id], vals))
                 i += 1
             try:
                 new_tels = vcard.contents.get('tel', [])[i:]
@@ -236,7 +236,8 @@ class Party:
 class Address:
     __name__ = 'party.address'
 
-    def vcard2values(self, adr):
+    @classmethod
+    def vcard2values(cls, adr):
         '''
         Convert adr from vcard to values for create or write
         '''
@@ -319,8 +320,7 @@ class VCard(Report):
                 adr = vcard.add('adr')
             if not hasattr(adr, 'value'):
                 adr.value = vobject.vcard.Address()
-            adr.value.street = address.street and address.street + (
-                address.streetbis and (" " + address.streetbis) or '') or ''
+            adr.value.street = address.street or ''
             adr.value.city = address.city or ''
             if address.subdivision:
                 adr.value.region = address.subdivision.name or ''
